@@ -91,13 +91,13 @@ class Activity(models.Model):
         Unless there is another content.object, in which case it will go to that and
         then get image. Sheesh.
 
-        Requires get_image() to be defined on the related model, 
+        Requires get_image() to be defined on the related model
         even if it just returns object.image, to avoid bringing back images you may not want.
 
         """
         obj = self.content_object
         if obj.get_image():
             return obj.get_image()
-        if obj.content_object and obj.content_object.get_image():
+        if obj.content_object.get_image():
             return obj.content_object.get_image()
         return None
